package com.book;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;
import java.sql.*;
import java.util.ArrayList;
import java.util.List;

public class BookDAOImpl implements BookDAO {
    private Connection conn;
    private DataSource dataSource;

    public BookDAOImpl(Connection conn) {
        {
            try {
                InitialContext context = new InitialContext();
                dataSource = (DataSource) context.lookup("java:comp/env/jdbc/MySQLDS");
            } catch (NamingException e) {
                throw new RuntimeException("Error initializing DataSource", e);
            }
                this.conn = conn;
        }
    }
    @Override
    public List<Book> listAllBooks() {
        List<Book> list = new ArrayList<>();
        try {
            Statement stmt = conn.createStatement();
            ResultSet rs = stmt.executeQuery("SELECT * FROM books");
            while (rs.next()) {
                Book book = new Book();
                book.setId(rs.getInt("id"));
                book.setTitle(rs.getString("title"));
                book.setAuthor(rs.getString("author"));
                list.add(book);
            }
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }
        return list;
    }

    @Override
    public void addBook(Book book) {
        try {
            PreparedStatement pstmt = conn.prepareStatement("INSERT INTO books (title, author) VALUES (?,?)");
            pstmt.setString(1, book.getTitle());
            pstmt.setString(2, book.getAuthor());
            pstmt.executeUpdate();
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void editBook(Book book) {
        try {
            PreparedStatement pstmt = conn.prepareStatement("UPDATE books SET title =?, author =? WHERE id =?");
            pstmt.setString(1, book.getTitle());
            pstmt.setString(2, book.getAuthor());
            pstmt.setInt(3, book.getId());
            pstmt.executeUpdate();
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void deleteBook(int id) {
        try {
            PreparedStatement pstmt = conn.prepareStatement("DELETE FROM books WHERE id =?");
            pstmt.setInt(1, id);
            pstmt.executeUpdate();
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }
    }
}
